/*
 *  header file for driver 'oms-pcixdrv.c'.  Does not present a user-space API.
 *
 *  Copyright(c) 2003 Oregon Micro Systems, Inc.  All rights reserved.
 */
#ifndef __PCIXDRV_H_
#define __PCIXDRV_H_

#include "oms-maxp.h"

#ifdef __KERNEL__

#define	INTERACTIVE_BUFFER_LEN	1024

// card specific data included in struct oms_card
struct hw_struct {
	// ******************************************************
	// physical addresses and mapped pointers into the card

	// physaddr (from pci config header BAR) of registers
	unsigned long   regbase_physaddr;
	// mapped address of register base
	unsigned long   regbase_addr;    // note that this is not a pointer

	volatile u32*   obisr;
	volatile u32*   obimr;
	volatile u32*   obmr0;
	volatile u32*   obmr1;
	volatile u32*		obdr;
	
	// physaddr (from pci config header BAR) of 64k shared memory
	unsigned long   shared64k_physaddr;
	// mapped address of shared memory
	u8*             shared64k;			// note that this IS a pointer
	
	volatile u32*		firmware;
	volatile u32*		limit;
	volatile u32*		home;
	volatile u32*		semaphore;
	volatile u32*		mailbox;
	
	//volatile u16*		cardnum;				// physical card ID
	//volatile u16*		vec_opcode;			// vector mode type
	//volatile u16*		vec_insert;			// vector queue insertion pointer
	//volatile u16*		vec_process;		// vector queue process pointer

	volatile char*	command_buf;
	volatile u32*		command_ip;
	volatile u32*		command_pp;
	volatile char*	response_buf;
	volatile u32*		response_ip;
	volatile u32*		response_pp;

	// physaddr (from pci config header BAR) of 512k shared memory
	unsigned long   shared512k_physaddr;
	// mapped address of shared memory
	u32*            shared512k;			// note that this IS a pointer
	
	// ******************************************************
	u8              status_flags;			// driver copy of status flags
	u8              done_flags;				// driver copy of done flags
	u8							pos_limit_flags;	// driver copy of positive limit flags
	u8							neg_limit_flags;	// driver copy of negative limit flags
	u8							slip_flags;				// driver copy of slip flags
};

// simplify access and expressions
#define	card_hw	((struct hw_struct*)(card->hardware))


// Hardware specific register definitions
#define REG_OBISR						0x00000030			//Outbound Interrupt Status Register
	#define REG_OBISR_MR0				0x0001				// Message Register 0
	#define REG_OBISR_MR1				0x0002				// Message Register 1
	#define REG_OBISR_DR				0x0008				// Data Register
#define REG_OBIMR						0x00000034			//Outbound Interrupt Mask Register
#define REG_OBMR0						0x00000058			//Outbound Message Register 0
	#define OBMR0_RESPONSE			0x00000001		// Response string available
	#define OBMR0_START_MASK		0x000FFF00		// Response Starting Index Mask
	#define OBMR0_START_SHIFT		8							// Response Starting Index Shift to 0
	#define OBMR0_LEN_MASK			0xFFF00000		// Response Length Mask
	#define OBMR0_LEN_SHIFT			20						// Response Length Shift to 0
#define REG_OBMR1						0x0000005C			//Outbound Message Register 1
	#define OBMR1_POSDATA				0x00000001		// Position data available
#define REG_OBDR						0x00000060			//Outbound Data Register
	#define OBDR_DONE_MASK			0x000000FF
	#define OBDR_DONE_SHIFT			0
	#define OBDR_LIMIT_MASK			0x0000FF00
	#define OBDR_LIMIT_SHIFT		8
	#define OBDR_SLIP_MASK			0x00FF0000
	#define OBDR_SLIP_SHIFT			16
	#define OBDR_CMDERR					0x01000000
	#define OBDR_CMDERR_SHIFT		24

// 64k Shared Memory Addresses the user doesn't really need to know about
#define MEM_RT_LIMIT				0x00000040			//Real Time Limit Switch Status
#define MEM_LIMIT_POS_MASK		0x000000FF
#define MEM_LIMIT_POS_SHIFT		0
#define MEM_LIMIT_NEG_MASK		0x0000FF00
#define MEM_LIMIT_NEG_SHIFT		8
#define MEM_RT_HOME					0x00000044			//Real Time Home Switch Status
#define MEM_FIRMWARE				0x00000048			//Firmware State
	#define MEM_FW_POWERUP			0xFFFFFFFF		// Power-up state, pre-init
	#define MEM_FW_DOWNLOAD			0x00000001		// Downloading
	#define MEM_FW_INITING			0x00000002		// Initializing
	#define MEM_FW_RUNNING			0x00000004		// Running
	#define MEM_FW_CKSUMERR			0x00000100		// Checksum Error
	#define MEM_FW_PGMERR				0x00000200		// Programming Error
	#define MEM_FW_CSERR1				0x00001000		// Checksum Error @ Parm Archive 1
	#define MEM_FW_PGERR1				0x00002000		// Programming Error @ Parm Archive 1
	#define MEM_FW_CSERR2				0x00004000		// Checksum Error @ Parm Archive 2
	#define MEM_FW_PGERR2				0x00008000		// Programming Error @ Parm Archive 2
	#define MEM_FW_DEFAULT			0x00010000		// Defaults Loaded
	#define MEM_FW_ALTERNATE		0x00020000		// Alternates Loaded
	#define MEM_FW_FACTORY			0x00040000		// Factory Defaults Loaded
#define MEM_DIRECT_MBOX			0x0000004C			//Direct Command Mailbox
	#define MEM_DMB_CMD_MASK		0x0000FFFF		// Host Command Mask
	#define MEM_DMB_STAT_MASK		0xFFFF0000		// Controller Status Mask
#define MEM_OM_SEMAPHORE		0x00000094			//Outbound Message Semaphore Register
	#define MEM_OMSEM_RESPONSE	0x00000001			// Response available in MEM_RESP_BUFFER
																							// write to block, clear to acknowledge
#define MEM_FLUSH_MBOX			0x00000098			//Command Buffer Flush Mailbox
#define MEM_FLASH_ADDRESS		0x000000EC			//Flash Program Address Pointer
#define MEM_CMD_INSERT			0x000000F0			//Command Buffer Insert Index
#define MEM_CMD_PROCESS			0x000000F4			//Command Buffer Process Index
#define MEM_RESP_INSERT			0x000000F8			//Response Buffer Insert Index
#define MEM_RESP_PROCESS		0x000000FC			//Response Buffer Process Index
#define MEM_CMD_BUFFER			0x00000100			//Command Ring Buffer
#define MEM_RESP_BUFFER			0x00000500			//Response Ring Buffer
#define MEM_EXCEPTION_LOG		0x00001100			//Exception Log


// initial interrupt mask
//#define INTERRUPT_MASK (REG_OBISR_MR0|REG_OBISR_MR1|REG_OBISR_DR)
#define INTERRUPT_MASK 0	//0xffffffff

// other defines
#define CARD_COMMAND_BUFFER_LEN		1024
#define CARD_RESPONSE_BUFFER_LEN	1024

extern struct tasklet_struct oms_tasklet;

#endif  // __KERNEL__
#endif  // __PCIXDRV_H_


