/* oms-pcix.h --- header file shared between driver and user-space
 *    programs.  Defines the physical PCIX hardware I/O.
 *
 *
 *  Copyright(c) 2003 Oregon Micro Systems, Inc.  All rights reserved.
 */

#ifndef __OMSPCIX_H_
#define __OMSPCIX_H_

#include "oms.h"	// core IOCTL calls, et. al.

//****************************************************************************
// HARDWARE SPECIFIC REGISTER AND BIT DEFINITIONS

// control and status bits
#define CMDERR_BIT              0x01  //Command error
#define INIT_BIT                0x02  //Controller is initializing
#define SLIP_BIT                0x04  //Axis encoder slip
#define OVRT_BIT                0x08  //Axis overtravel
#define DONE_BIT                0x10  //Done condition
#define IBF_BIT                 0x20  //Character received from controller
#define TBE_BIT                 0x40  //Controller ready to receive a character
#define IRQ_BIT                 0x80  //Controller interrupt master enable
// done register bits
#define AXIS_X                  0x01
#define AXIS_Y                  0x02
#define AXIS_Z                  0x04
#define AXIS_T                  0x08
#define AXIS_U                  0x10
#define AXIS_V                  0x20
#define AXIS_R                  0x40
#define AXIS_S                  0x80

// interesting shared memory offsets (from shared_mem base)
#define OMS_MEM_CARDNUM         0x00000000

#define OMS_MEM_MAILBOX         0x00000010
// <mailbox codes>
#define MAILBOX_MOTOR           0x0001
#define MAILBOX_ENCODER         0x0002
#define MAILBOX_BOTH            0x0003
// </mailbox codes>

#define OMS_MEM_MOTOR_X         0x00000020
#define OMS_MEM_MOTOR_Y         0x00000024
#define OMS_MEM_MOTOR_Z         0x00000028
#define OMS_MEM_MOTOR_T         0x0000002C
#define OMS_MEM_MOTOR_U         0x00000030
#define OMS_MEM_MOTOR_V         0x00000034
#define OMS_MEM_MOTOR_R         0x00000038
#define OMS_MEM_MOTOR_S         0x0000003C

#define OMS_MEM_ENCODER_X       0x00000040
#define OMS_MEM_ENCODER_Y       0x00000044
#define OMS_MEM_ENCODER_Z       0x00000048
#define OMS_MEM_ENCODER_T       0x0000004C
#define OMS_MEM_ENCODER_U       0x00000050
#define OMS_MEM_ENCODER_V       0x00000054
#define OMS_MEM_ENCODER_R       0x00000058
#define OMS_MEM_ENCODER_S       0x0000005C

#define OMS_MEM_VEC_OPCODE      0x000000E8
#define OMS_MEM_VEC_INSERT      0x000000F0
#define OMS_MEM_VEC_PROCESS     0x000000F8

#endif // __OMSPCIX_H_
